@@ -53,6 +53,10 @@ static void                 pulseaudio_volume_get_source_list_cb (pa_context
                                                                   const pa_source_info *i,
                                                                   int                   eol,
                                                                   void                 *userdata);
+static void                 pulseaudio_volume_move_sink_input    (pa_context           *context,
+                                                                  const                 pa_sink_input_info *i,
+                                                                  int                   eol,
+                                                                  void                 *userdata);
 
 
 
@@ -536,6 +540,26 @@ pulseaudio_volume_get_connected (PulseaudioVolume *volume)
 
 
 
+gboolean
+pulseaudio_volume_get_sink_connected (PulseaudioVolume *volume)
+{
+  g_return_val_if_fail (IS_PULSEAUDIO_VOLUME (volume), FALSE);
+
+  return volume->sink_connected;
+}
+
+
+
+gboolean
+pulseaudio_volume_get_source_connected (PulseaudioVolume *volume)
+{
+  g_return_val_if_fail (IS_PULSEAUDIO_VOLUME (volume), FALSE);
+
+  return volume->source_connected;
+}
+
+
+
 static gdouble
 pulseaudio_volume_v2d (PulseaudioVolume *volume,
                        pa_volume_t       pa_volume)
@@ -737,10 +761,10 @@ pulseaudio_volume_set_volume (PulseaudioVolume *volume,
   vol_trim = MIN (MAX (vol, 0.0), vol_max);
 
   if (volume->volume != vol_trim)
-    {
-      volume->volume = vol_trim;
-      pa_context_get_server_info (volume->pa_context, pulseaudio_volume_set_volume_cb1, volume);
-    }
+  {
+    volume->volume = vol_trim;
+    pa_context_get_server_info (volume->pa_context, pulseaudio_volume_set_volume_cb1, volume);
+  }
 }
 
 
@@ -905,6 +929,8 @@ pulseaudio_volume_default_sink_changed_info_cb (pa_context         *context,
 
   pa_context_move_sink_input_by_index (context, volume->sink_index, i->index, NULL, NULL);
   volume->sink_index = (guint)i->index;
+
+  pa_context_get_sink_input_info_list (volume->pa_context, pulseaudio_volume_move_sink_input, volume);
 }
 
 
@@ -922,6 +948,22 @@ pulseaudio_volume_default_sink_changed (pa_context *context,
 
 
 
+static void
+pulseaudio_volume_move_sink_input (pa_context               *context,
+                                   const pa_sink_input_info *i,
+                                   int                       eol,
+                                   void                     *userdata)
+{
+  PulseaudioVolume *volume = PULSEAUDIO_VOLUME (userdata);
+
+  if (i == NULL) return;
+  if (eol > 0) return;
+
+  pa_context_move_sink_input_by_name (context, i->index, volume->default_sink_name, NULL, NULL);
+}
+
+
+
 void
 pulseaudio_volume_set_default_output (PulseaudioVolume *volume,
                                       const gchar      *name)
